==> gst-plugins-bad-free-1.22.4-loong64-2.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libgstadaptivedemux-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstadaptivedemux-1.0.so.0.2204.0 libgstadaptivedemux-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstadaptivedemux-1.0.so )
( cd usr/lib64 ; ln -sf libgstadaptivedemux-1.0.so.0 libgstadaptivedemux-1.0.so )
( cd usr/lib64 ; rm -rf libgstbadaudio-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstbadaudio-1.0.so.0.2204.0 libgstbadaudio-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstbadaudio-1.0.so )
( cd usr/lib64 ; ln -sf libgstbadaudio-1.0.so.0 libgstbadaudio-1.0.so )
( cd usr/lib64 ; rm -rf libgstbasecamerabinsrc-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstbasecamerabinsrc-1.0.so.0.2204.0 libgstbasecamerabinsrc-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstbasecamerabinsrc-1.0.so )
( cd usr/lib64 ; ln -sf libgstbasecamerabinsrc-1.0.so.0 libgstbasecamerabinsrc-1.0.so )
( cd usr/lib64 ; rm -rf libgstcodecparsers-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstcodecparsers-1.0.so.0.2204.0 libgstcodecparsers-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstcodecparsers-1.0.so )
( cd usr/lib64 ; ln -sf libgstcodecparsers-1.0.so.0 libgstcodecparsers-1.0.so )
( cd usr/lib64 ; rm -rf libgstcodecs-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstcodecs-1.0.so.0.2204.0 libgstcodecs-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstcodecs-1.0.so )
( cd usr/lib64 ; ln -sf libgstcodecs-1.0.so.0 libgstcodecs-1.0.so )
( cd usr/lib64 ; rm -rf libgstcuda-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstcuda-1.0.so.0.2204.0 libgstcuda-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstcuda-1.0.so )
( cd usr/lib64 ; ln -sf libgstcuda-1.0.so.0 libgstcuda-1.0.so )
( cd usr/lib64 ; rm -rf libgstinsertbin-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstinsertbin-1.0.so.0.2204.0 libgstinsertbin-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstinsertbin-1.0.so )
( cd usr/lib64 ; ln -sf libgstinsertbin-1.0.so.0 libgstinsertbin-1.0.so )
( cd usr/lib64 ; rm -rf libgstisoff-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstisoff-1.0.so.0.2204.0 libgstisoff-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstisoff-1.0.so )
( cd usr/lib64 ; ln -sf libgstisoff-1.0.so.0 libgstisoff-1.0.so )
( cd usr/lib64 ; rm -rf libgstmpegts-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstmpegts-1.0.so.0.2204.0 libgstmpegts-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstmpegts-1.0.so )
( cd usr/lib64 ; ln -sf libgstmpegts-1.0.so.0 libgstmpegts-1.0.so )
( cd usr/lib64 ; rm -rf libgstopencv-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstopencv-1.0.so.0.2204.0 libgstopencv-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstopencv-1.0.so )
( cd usr/lib64 ; ln -sf libgstopencv-1.0.so.0 libgstopencv-1.0.so )
( cd usr/lib64 ; rm -rf libgstphotography-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstphotography-1.0.so.0.2204.0 libgstphotography-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstphotography-1.0.so )
( cd usr/lib64 ; ln -sf libgstphotography-1.0.so.0 libgstphotography-1.0.so )
( cd usr/lib64 ; rm -rf libgstplay-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstplay-1.0.so.0.2204.0 libgstplay-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstplay-1.0.so )
( cd usr/lib64 ; ln -sf libgstplay-1.0.so.0 libgstplay-1.0.so )
( cd usr/lib64 ; rm -rf libgstplayer-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstplayer-1.0.so.0.2204.0 libgstplayer-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstplayer-1.0.so )
( cd usr/lib64 ; ln -sf libgstplayer-1.0.so.0 libgstplayer-1.0.so )
( cd usr/lib64 ; rm -rf libgstsctp-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstsctp-1.0.so.0.2204.0 libgstsctp-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstsctp-1.0.so )
( cd usr/lib64 ; ln -sf libgstsctp-1.0.so.0 libgstsctp-1.0.so )
( cd usr/lib64 ; rm -rf libgsttranscoder-1.0.so )
( cd usr/lib64 ; ln -sf libgsttranscoder-1.0.so.0 libgsttranscoder-1.0.so )
( cd usr/lib64 ; rm -rf libgsturidownloader-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgsturidownloader-1.0.so.0.2204.0 libgsturidownloader-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgsturidownloader-1.0.so )
( cd usr/lib64 ; ln -sf libgsturidownloader-1.0.so.0 libgsturidownloader-1.0.so )
( cd usr/lib64 ; rm -rf libgstva-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstva-1.0.so.0.2204.0 libgstva-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstva-1.0.so )
( cd usr/lib64 ; ln -sf libgstva-1.0.so.0 libgstva-1.0.so )
( cd usr/lib64 ; rm -rf libgstvulkan-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstvulkan-1.0.so.0.2204.0 libgstvulkan-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstvulkan-1.0.so )
( cd usr/lib64 ; ln -sf libgstvulkan-1.0.so.0 libgstvulkan-1.0.so )
( cd usr/lib64 ; rm -rf libgstwayland-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstwayland-1.0.so.0.2204.0 libgstwayland-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstwayland-1.0.so )
( cd usr/lib64 ; ln -sf libgstwayland-1.0.so.0 libgstwayland-1.0.so )
( cd usr/lib64 ; rm -rf libgstwebrtc-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstwebrtc-1.0.so.0.2204.0 libgstwebrtc-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstwebrtc-1.0.so )
( cd usr/lib64 ; ln -sf libgstwebrtc-1.0.so.0 libgstwebrtc-1.0.so )
( cd usr/lib64 ; rm -rf libgstwebrtcnice-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstwebrtcnice-1.0.so.0.2204.0 libgstwebrtcnice-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstwebrtcnice-1.0.so )
( cd usr/lib64 ; ln -sf libgstwebrtcnice-1.0.so.0 libgstwebrtcnice-1.0.so )

==> gst-plugins-bad-free-1.24.9-loong64-1.txz: install/doinst.sh <==
( cd usr/lib64 ; rm -rf libgstadaptivedemux-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstadaptivedemux-1.0.so.0.2409.0 libgstadaptivedemux-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstadaptivedemux-1.0.so )
( cd usr/lib64 ; ln -sf libgstadaptivedemux-1.0.so.0 libgstadaptivedemux-1.0.so )
( cd usr/lib64 ; rm -rf libgstanalytics-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstanalytics-1.0.so.0.2409.0 libgstanalytics-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstanalytics-1.0.so )
( cd usr/lib64 ; ln -sf libgstanalytics-1.0.so.0 libgstanalytics-1.0.so )
( cd usr/lib64 ; rm -rf libgstbadaudio-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstbadaudio-1.0.so.0.2409.0 libgstbadaudio-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstbadaudio-1.0.so )
( cd usr/lib64 ; ln -sf libgstbadaudio-1.0.so.0 libgstbadaudio-1.0.so )
( cd usr/lib64 ; rm -rf libgstbasecamerabinsrc-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstbasecamerabinsrc-1.0.so.0.2409.0 libgstbasecamerabinsrc-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstbasecamerabinsrc-1.0.so )
( cd usr/lib64 ; ln -sf libgstbasecamerabinsrc-1.0.so.0 libgstbasecamerabinsrc-1.0.so )
( cd usr/lib64 ; rm -rf libgstcodecparsers-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstcodecparsers-1.0.so.0.2409.0 libgstcodecparsers-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstcodecparsers-1.0.so )
( cd usr/lib64 ; ln -sf libgstcodecparsers-1.0.so.0 libgstcodecparsers-1.0.so )
( cd usr/lib64 ; rm -rf libgstcodecs-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstcodecs-1.0.so.0.2409.0 libgstcodecs-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstcodecs-1.0.so )
( cd usr/lib64 ; ln -sf libgstcodecs-1.0.so.0 libgstcodecs-1.0.so )
( cd usr/lib64 ; rm -rf libgstcuda-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstcuda-1.0.so.0.2409.0 libgstcuda-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstcuda-1.0.so )
( cd usr/lib64 ; ln -sf libgstcuda-1.0.so.0 libgstcuda-1.0.so )
( cd usr/lib64 ; rm -rf libgstdxva-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstdxva-1.0.so.0.2409.0 libgstdxva-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstdxva-1.0.so )
( cd usr/lib64 ; ln -sf libgstdxva-1.0.so.0 libgstdxva-1.0.so )
( cd usr/lib64 ; rm -rf libgstinsertbin-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstinsertbin-1.0.so.0.2409.0 libgstinsertbin-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstinsertbin-1.0.so )
( cd usr/lib64 ; ln -sf libgstinsertbin-1.0.so.0 libgstinsertbin-1.0.so )
( cd usr/lib64 ; rm -rf libgstisoff-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstisoff-1.0.so.0.2409.0 libgstisoff-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstisoff-1.0.so )
( cd usr/lib64 ; ln -sf libgstisoff-1.0.so.0 libgstisoff-1.0.so )
( cd usr/lib64 ; rm -rf libgstmpegts-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstmpegts-1.0.so.0.2409.0 libgstmpegts-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstmpegts-1.0.so )
( cd usr/lib64 ; ln -sf libgstmpegts-1.0.so.0 libgstmpegts-1.0.so )
( cd usr/lib64 ; rm -rf libgstmse-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstmse-1.0.so.0.2409.0 libgstmse-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstmse-1.0.so )
( cd usr/lib64 ; ln -sf libgstmse-1.0.so.0 libgstmse-1.0.so )
( cd usr/lib64 ; rm -rf libgstopencv-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstopencv-1.0.so.0.2409.0 libgstopencv-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstopencv-1.0.so )
( cd usr/lib64 ; ln -sf libgstopencv-1.0.so.0 libgstopencv-1.0.so )
( cd usr/lib64 ; rm -rf libgstphotography-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstphotography-1.0.so.0.2409.0 libgstphotography-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstphotography-1.0.so )
( cd usr/lib64 ; ln -sf libgstphotography-1.0.so.0 libgstphotography-1.0.so )
( cd usr/lib64 ; rm -rf libgstplay-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstplay-1.0.so.0.2409.0 libgstplay-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstplay-1.0.so )
( cd usr/lib64 ; ln -sf libgstplay-1.0.so.0 libgstplay-1.0.so )
( cd usr/lib64 ; rm -rf libgstplayer-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstplayer-1.0.so.0.2409.0 libgstplayer-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstplayer-1.0.so )
( cd usr/lib64 ; ln -sf libgstplayer-1.0.so.0 libgstplayer-1.0.so )
( cd usr/lib64 ; rm -rf libgstsctp-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstsctp-1.0.so.0.2409.0 libgstsctp-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstsctp-1.0.so )
( cd usr/lib64 ; ln -sf libgstsctp-1.0.so.0 libgstsctp-1.0.so )
( cd usr/lib64 ; rm -rf libgsttranscoder-1.0.so )
( cd usr/lib64 ; ln -sf libgsttranscoder-1.0.so.0 libgsttranscoder-1.0.so )
( cd usr/lib64 ; rm -rf libgsturidownloader-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgsturidownloader-1.0.so.0.2409.0 libgsturidownloader-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgsturidownloader-1.0.so )
( cd usr/lib64 ; ln -sf libgsturidownloader-1.0.so.0 libgsturidownloader-1.0.so )
( cd usr/lib64 ; rm -rf libgstva-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstva-1.0.so.0.2409.0 libgstva-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstva-1.0.so )
( cd usr/lib64 ; ln -sf libgstva-1.0.so.0 libgstva-1.0.so )
( cd usr/lib64 ; rm -rf libgstvulkan-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstvulkan-1.0.so.0.2409.0 libgstvulkan-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstvulkan-1.0.so )
( cd usr/lib64 ; ln -sf libgstvulkan-1.0.so.0 libgstvulkan-1.0.so )
( cd usr/lib64 ; rm -rf libgstwayland-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstwayland-1.0.so.0.2409.0 libgstwayland-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstwayland-1.0.so )
( cd usr/lib64 ; ln -sf libgstwayland-1.0.so.0 libgstwayland-1.0.so )
( cd usr/lib64 ; rm -rf libgstwebrtc-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstwebrtc-1.0.so.0.2409.0 libgstwebrtc-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstwebrtc-1.0.so )
( cd usr/lib64 ; ln -sf libgstwebrtc-1.0.so.0 libgstwebrtc-1.0.so )
( cd usr/lib64 ; rm -rf libgstwebrtcnice-1.0.so.0 )
( cd usr/lib64 ; ln -sf libgstwebrtcnice-1.0.so.0.2409.0 libgstwebrtcnice-1.0.so.0 )
( cd usr/lib64 ; rm -rf libgstwebrtcnice-1.0.so )
( cd usr/lib64 ; ln -sf libgstwebrtcnice-1.0.so.0 libgstwebrtcnice-1.0.so )
